pub struct DecideRequest {
pub state: Value,
pub questions: BTreeMap<String, Question>,
pub deadline: Option<Duration>,
}Expand description
One decision call.
Fields
state: ValueWhat is being judged: a string, object or array.
questions: BTreeMap<String, Question>deadline: Option<Duration>Per-call budget; None = the backend’s (or chain’s) default.
Implementations
Sourceimpl DecideRequest
impl DecideRequest
pub fn new( state: impl Into<Value>, questions: BTreeMap<String, Question>, ) -> Self
pub fn with_deadline(self, deadline: Option<Duration>) -> Self
Sourcepub fn validate(&self) -> Result<(), DecideError>
pub fn validate(&self) -> Result<(), DecideError>
DEC-E006 unless there is at least one question and every question
is askable, and state is a string, object or array.